'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

var _isObservable = require('is-observable');

var _isObservable2 = _interopRequireDefault(_isObservable);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var messagesToStream = function messagesToStream(subject) {
  return function () {
    return subject.next.apply(subject, arguments);
  };
};

/**
 * Turns an object whose values are Rx.Subjects, into an object with the
 * same keys, but their values are not Subjects but functions, that
 * may be called directly with data you want to push to Subject.
 * So instead of using `userClicks$.next('buttonX')`
 * once you do `const userClicked = createPushMessageFunctions(userClicks)` and then
 * just use `userClicked('buttonX')`.
 *
 * For convenience, you can also pass a single Subject as the first argument,
 * and get a function in return.
 *
 * @param {Observable|Object} Subject An object whose values are Rx.Subject.
 * You may also pass a single Observable.
 *
 * @returns {Function|Object} Object mimicking the original object, but with
 * values changed from Rx.Subject to ordinary functions you can call with
 * values that will be passed to the Subject as `.next()`.
 */
var createPushMessageFunctions = function createPushMessageFunctions(subjects) {
  if ((0, _isObservable2['default'])(subjects)) return messagesToStream(subjects);

  if ((typeof subjects === 'undefined' ? 'undefined' : (0, _typeof3['default'])(subjects)) !== 'object' || subjects === null) {
    throw new Error('messagesToStreams expected an object or a function,\n      instead received: ' + (subjects === null ? 'null' : typeof subjects === 'undefined' ? 'undefined' : (0, _typeof3['default'])(subjects)) + '.');
  }

  return (0, _keys2['default'])(subjects).reduce(function (acc, key) {
    var subject = subjects[key];
    if ((0, _isObservable2['default'])(subject)) {
      acc[key] = messagesToStream(subject);
    }
    return acc;
  }, {});
};

exports['default'] = createPushMessageFunctions;