'use strict';

exports.__esModule = true;

var _rxjs = require('rxjs');

var _rxjs2 = _interopRequireDefault(_rxjs);

var _createPushMessageFunctions = require('./createPushMessageFunctions');

var _createPushMessageFunctions2 = _interopRequireDefault(_createPushMessageFunctions);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

/**
 * Turns an array of names, into an object where keys are these names
 * with added '$' on the end (good practice to identify streams)
 * and the values are Rx.Subjects.
 *
 * @param {Array|String} names An object whose values are `Rx.Subject`s.
 * You may also pass a single function.
 *
 * @param {Boolean} makePushFunctions If you want create the
 * `pushMessageFunctions`, too. Default is true.
 *
 * @returns {Object} messageStreams Object with keys like {
 *   arrayItem$: Rx.Subject,
 *   arrayItem: (val) => arrayItem$.next(val),
 *   anotherArrayItem: ...
 * }
 */
var createMessageStreams = function createMessageStreams(names) {
  var makePushMessageFunctions = arguments.length <= 1 || arguments[1] === undefined ? true : arguments[1];

  var namesArr = [].concat(names);
  return namesArr.reduce(function (acc, itemName) {
    if (typeof itemName === 'string') {
      var streamName = itemName + '$';
      acc[streamName] = new _rxjs2['default'].Subject();
      if (makePushMessageFunctions) acc[itemName] = (0, _createPushMessageFunctions2['default'])(acc[streamName]);
    }
    return acc;
  }, {});
};

// IDEA: possible to submit structure, not jut flat array

exports['default'] = createMessageStreams;