'use strict';

exports.__esModule = true;

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

var _rxjs = require('rxjs');

var _rxjs2 = _interopRequireDefault(_rxjs);

var _isObservable = require('is-observable');

var _isObservable2 = _interopRequireDefault(_isObservable);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

/**
 * creates observable application state (stream)
 * You can subsrcibe to this stream and get the current state object
 * and new object every time the state changes.
 *
 * @param   {Observable} reducer$ Stream of reducer functions
 * @param   {Observable|Object} initialState Initial state may be Observable
 *          or object (will be converted to Observable)
 * @returns {Observable} Observable stream of current state
 */
var createState = function createState(reducer$) {
  var initialState = arguments.length <= 1 || arguments[1] === undefined ? _rxjs2['default'].Observable.of({}) : arguments[1];

  if (!(0, _isObservable2['default'])(reducer$)) {
    throw new Error('createState expects first argument - reducer - to be Observable\n    but it is ' + (reducer$ === null ? 'null' : typeof reducer$ === 'undefined' ? 'undefined' : (0, _typeof3['default'])(reducer$)));
  }

  if (!(0, _isObservable2['default'])(initialState) && (typeof initialState === 'undefined' ? 'undefined' : (0, _typeof3['default'])(initialState)) !== 'object') {
    throw new Error('createState expects second argument - initialState\n      to be Observable or Object\n      but it is ' + (initialState === null ? 'null' : typeof initialState === 'undefined' ? 'undefined' : (0, _typeof3['default'])(initialState)));
  }

  var initialState$ = (0, _isObservable2['default'])(initialState) ? initialState : _rxjs2['default'].Observable.of(initialState);

  return initialState$.merge(reducer$).scan(function (state, reducer) {
    return reducer(state);
  }).publishReplay(1).refCount();
};

exports['default'] = createState;